#if !defined(__ISO_MESSAGE_H)
#define __ISO_MESSAGE_H

/**************************************************************************
 * File Name :		isomessage.h
 * 
 * Description : 	Definitions common to all ISO messages.
 *
 * Author : 		Ben Lurie
 *
 * Date Created : 	10/29/95
 *
 * Modified :
 *	Ranga, 11/08/95 : changed the enum definition for processing code to 
 *		assign AMEX-defined values.
 **************************************************************************
 */

#if defined(sun4)
#include <sys/param.h>
#include <memory.h>
#elif defined(sun)
#include <sys/types.h>
#include <sys/bitmap.h>
#elif defined(aix)
#define _ALL_SOURCE 
#define const
#include <sys/param.h>
#include <memory.h>
#include <sys/types.h>
#endif

/*
 * Define TRUE and FALSE if not already defined.
 */
#if !defined(TRUE)
#define TRUE 1
#endif
#if !defined(FALSE)
#define FALSE 0
#endif

/*
 * Define bit manipulation routines: set, clear, test.
 */

#if defined(sun4) || defined(aix)

#define IsoSetBit(bitMapPtr, bitPosition) setbit(bitMapPtr, bitPosition)
#define IsoClearBit(bitMapPtr, bitPosition) clrbit(bitMapPtr, bitPosition)
#define IsoTestBit(bitMapPtr, bitPosition) (isset(bitMapPtr, bitPosition) != 0)

#elif defined(sun)

#define IsoSetBit(bitMapPtr, bitPosition) \
	BT_SET(((unsigned long*)bitMapPtr),  bitPosition)
#define IsoClearBit(bitMapPtr, bitPosition) \
	BT_CLEAR(((unsigned long *)bitMapPtr), bitPosition)
#define IsoTestBit(bitMapPtr, bitPosition) \
	BT_TEST(((unsigned long *)bitMapPtr), bitPosition)

#endif /* defined(sun) */

/*
 * This enumeration is a list of all of the status codes that the ISO 
 * message can return.
 *
 * NOTE:
 *		It *must* be coordinated with the errorStrings array defined
 *		in isomessage.c.  If you change this enumeration, you must
 *		change the errorStrings array.
 */
typedef enum
{
	VALID = 1,
	ENOMEM,
	OUTPUT_BUFFER_TOO_SMALL,
	NODATA,
	INVALID_BIT_POSITION,
	INVALID,
	ISO1100_ACCOUNT_NO_INVALID,
	ISO1100_AMOUNT_INVALID,
	ISO1100_CURRENCY_CODE_INVALID,
	ISO1100_DATE_EFFECTIVE_INVALID,
	ISO1100_DATE_EXPIRATION_INVALID,
	ISO1100_MERCHANT_TYPE_INVALID,
	ISO1100_COUNTRY_CODE_INVALID,
	ISO1100_POS_DATA_CODE_INVALID,
	ISO1100_FUNCTION_CODE_INVALID,
	ISO1100_MESSAGE_REASON_CODE_INVALID,
	ISO1100_CARD_ACCEPTOR_BUS_CODE_INVALID,
	ISO1100_APPROVAL_CODE_LENGTH_INVALID,
	ISO1100_PROCESSING_CODE_INVALID,
	ISO1100_ACCEPT_TERM_ID_INVALID,
	ISO1100_CARD_ACCEPT_ID_INVALID,
	ISO1100_CARD_ACCEPT_LOCATION_INVALID,
	ISO1100_SYSTEM_TRACE_INVALID,
	ISO1100_SECURITY_INFO_INVALID,
	ISO1100_PRIVATE1_DATA_INVALID,
	ISO1100_PRIVATE2_DATA_INVALID,
	ISO1100_ACQUIRE_INST_ID_INVALID,
	ISO1100_FORWARD_ID_INVALID,
	ISO1100_TRACK1_DATA_INVALID,
	ISO1100_TRACK2_DATA_INVALID,
	ISO1100_RETRIEVAL_REF_INVALID,
	__ISO_MESSAGE_STATUS_LAST	/* Not used */
} IsoMessageStatus;

/*
 * This enumeration defines the set of processing codes that are
 * used by the ISO messages.  They directly correspond to the 
 * processing codes defined by ISO 8583.
 */
/* Ranga, 11/08/95, changed processing code values to corr. to AMEX-defined
   values.
*/
typedef enum
{
	CC_AUTHENTICATION = 4000,
	CC_REVERSAL,
	CC_AUTHENTICATION_ADDRESS_VERIFICATION = 4800,
	AMEX_EMERGENCY_CHECK_CASHING = 34000,
	CHECK_GUARANTEE = 44000,
	AMEX_TRAVELERS_CHECK = 64000,
	AMEX_SIGHT_DRAFT = 104000,
	ADDRESS_VERIFICATION = 174800,
	__LAST_ITEM				/* Do not use */
} IsoProcCode;

/*
 * This enumeration defines the set of character types that the ISO
 * messages can handle as input and output.
 */
typedef enum
{
	ASCII,
	EBCDIC
} IsoCharacterType;

typedef struct IsoCurrencyCode_t 
{
	char *code; 
	unsigned int decimalPoint; 
} IsoCurrencyCode;

extern char* errorStrings[__ISO_MESSAGE_STATUS_LAST];

#endif /* !defined(__ISO_MESSAGE_H) */
