#if !defined(__ISO_MESSAGE_BYTE_STREAM_H)
#define __ISO_MESSAGE_BYTE_STREAM_H

#include <stddef.h>

#include "isomessage.h"

#define	ISO_MESSAGE_NUM_BITS	(64)

typedef struct BitPositionDesc_t
{
	int	isVariableLength;
	union
	{
		unsigned short		variableLengthIndicationSize;
		unsigned short		size;
	} positionSize;
} BitPositionDesc;

typedef	BitPositionDesc BitPositionDescArray[ISO_MESSAGE_NUM_BITS];

typedef char IsoMessageType[4];

typedef IsoMessageStatus IsoMessageByteStreamStatus;

typedef struct IsoMessageByteStream_t
{

	/********************************************************/
	/* Public Interface */
	/********************************************************/

	const IsoMessageByteStreamStatus	
		(*setValue)(struct IsoMessageByteStream_t *,
					const unsigned short position,
					const void* valuePtr);

	const IsoMessageByteStreamStatus	
		(*getValue)(struct IsoMessageByteStream_t *,
					const unsigned short position,
					const unsigned short numBytesInValueArray,
					void* valuePtr,
					size_t*	numBytesReturnedPtr);

	const IsoMessageByteStreamStatus	
		(*unsetValue)(struct IsoMessageByteStream_t *,
					  const unsigned short position);

	const void *
		(*getByteStream)(struct IsoMessageByteStream_t *, size_t*);

	const IsoMessageByteStreamStatus	
		(*status)(const struct IsoMessageByteStream_t *);

	/********************************************************/
	/* Private Interface
	/********************************************************/

	IsoMessageByteStreamStatus	_status;
	BitPositionDescArray		descArray;

	size_t						byteStreamSize;
	void*						byteStreamPtr;

	void*						currentDataPtr;
	unsigned short						currentBitPosition;
} IsoMessageByteStream;

extern IsoMessageByteStream*	
	initIsoMessageByteStream(const IsoMessageType messageType,
							 const BitPositionDescArray);
extern IsoMessageByteStream*	
	initIsoMessageByteStreamFromStream(const void* byteStreamPtr,
									   const size_t streamSize,
									   const BitPositionDescArray);
extern void deleteIsoMessageByteStream(IsoMessageByteStream*);
	
#endif /* !defined(__ISO_MESSAGE_BYTE_STREAM_H) */
